pilas.evento.Evento

Package pilas :: Module evento :: Class Evento |
[hide private]
[frames] | no frames]

# Class Evento

source code

Instance Methods | [hide private]
__init__(self, nombre) | source code
emitir(self, **evento) | source code
conectar(self, respuesta, id=None) | source code
desconectar(self, respuesta) | source code
desconectar_por_id(self, id) | source code
esta_conectado(self) | source code
imprimir_funciones_conectadas(self) | source code